@@ -10,40 +10,32 @@
 
 {-|
 Module:      TextShow.Data.Proxy
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Monomorphic 'TextShow' function for 'Proxy' values.
+'TextShow' instance for 'Proxy'.
 
 /Since: 2/
 -}
-module TextShow.Data.Proxy (showbProxy) where
+module TextShow.Data.Proxy () where
 
-import Data.Proxy (Proxy(..))
-import Data.Text.Lazy.Builder (Builder)
+import Data.Proxy (Proxy)
 
 import TextShow.Classes (TextShow(..))
 import TextShow.TH.Internal (deriveTextShow1, makeShowbPrec,
                              makeShowtPrec, makeShowtlPrec)
 
-#include "inline.h"
-
--- | Convert a 'Proxy' type to a 'Builder'.
---
--- /Since: 2/
-showbProxy :: Proxy s -> Builder
-showbProxy = showb
-{-# INLINE showbProxy #-}
-
+-- | /Since: 2/
 instance TextShow (Proxy s) where
     showbPrec  = $(makeShowbPrec  ''Proxy)
     showtPrec  = $(makeShowtPrec  ''Proxy)
     showtlPrec = $(makeShowtlPrec ''Proxy)
-    INLINE_INST_FUN(showbPrec)
-    INLINE_INST_FUN(showtPrec)
-    INLINE_INST_FUN(showtlPrec)
+    {-# INLINE showbPrec #-}
+    {-# INLINE showtPrec #-}
+    {-# INLINE showtlPrec #-}
 
+-- | /Since: 2/
 $(deriveTextShow1 ''Proxy)
