@@ -1,6 +1,6 @@
 {-|
 Module:      Spec.Control.ApplicativeSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -14,14 +14,14 @@ import Control.Applicative (Const, ZipList)
 import Control.Monad.Trans.Instances ()
 
 import Data.Orphans ()
+import Data.Proxy (Proxy(..))
 
 import Generics.Deriving.Instances ()
 
-import Spec.Utils (prop_matchesTextShow, prop_matchesTextShow1,
-                   prop_genericTextShow, prop_genericTextShow1)
+import Spec.Utils (matchesTextShowSpec, matchesTextShow1Spec,
+                   genericTextShowSpec, genericTextShow1Spec)
 
 import Test.Hspec (Spec, describe, hspec, parallel)
-import Test.Hspec.QuickCheck (prop)
 
 main :: IO ()
 main = hspec spec
@@ -29,8 +29,10 @@ main = hspec spec
 spec :: Spec
 spec = parallel $ do
     describe "Const Int Int" $
-        prop "TextShow1 instance" (prop_matchesTextShow1 :: Int -> Const Int Int -> Bool)
+        matchesTextShow1Spec (Proxy :: Proxy (Const Int Int))
     describe "ZipList Int" $ do
-        prop "TextShow instance"  (prop_matchesTextShow  :: Int -> ZipList Int -> Bool)
-        prop "generic TextShow"   (prop_genericTextShow  :: Int -> ZipList Int -> Bool)
-        prop "generic TextShow1"  (prop_genericTextShow1 :: Int -> ZipList Int -> Bool)
+        let p :: Proxy (ZipList Int)
+            p = Proxy
+        matchesTextShowSpec  p
+        genericTextShowSpec  p
+        genericTextShow1Spec p
