@@ -27,7 +27,7 @@ import Spec.Utils (matchesTextShowSpec)
 
 import Test.Hspec (Spec, describe, hspec, parallel)
 import Test.Hspec.QuickCheck (prop)
-import Test.QuickCheck (Property, (==>))
+import Test.QuickCheck (Property, arbitrary, property, suchThat)
 
 import TextShow (Builder, fromString)
 import TextShow.Data.Floating (showbEFloat, showbFFloat, showbGFloat,
@@ -59,11 +59,14 @@ spec = parallel $ do
 -- is one of E, F, or G).
 prop_showXFloat :: (Maybe Int -> Double -> ShowS)
                 -> (Maybe Int -> Double -> Builder)
-                -> Maybe Int -> Double -> Property
-prop_showXFloat f1 f2 mb_digs val =
-  mb_digs /= Nothing && mb_digs <= Just 10
+                -> Double -> Property
+prop_showXFloat f1 f2 val = property $ do
+  mb_digs <- arbitrary `suchThat` cond
+  pure $ fromString (f1 mb_digs val "") == f2 mb_digs val
+  where
+    cond :: Maybe Int -> Bool
+    cond mb_digs =
+      mb_digs /= Nothing && mb_digs <= Just 10
 #if !(MIN_VERSION_base(4,12,0))
-    && mb_digs /= Just 0 -- Work around Trac #15115
+      && mb_digs > Just 0 -- Work around Trac #15115
 #endif
-      ==>
-    fromString (f1 mb_digs val "") == f2 mb_digs val
