@@ -17,6 +17,8 @@ import Data.Proxy (Proxy(..))
 
 import Generics.Deriving.Instances ()
 
+import Instances.Data.Monoid ()
+
 import Spec.Utils (matchesTextShowSpec, genericTextShowSpec, genericTextShow1Spec)
 
 import Test.Hspec (Spec, describe, hspec, parallel)
@@ -74,3 +76,11 @@ spec = parallel $ do
         genericTextShowSpec  p
         genericTextShow1Spec p
 #endif
+#if MIN_VERSION_base(4,12,0)
+    describe "Ap Maybe Int" $ do
+        let p :: Proxy (Ap Maybe Int)
+            p = Proxy
+        matchesTextShowSpec  p
+        genericTextShowSpec  p
+        genericTextShow1Spec p
+#endif
