@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.Data.Type.CoercionSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -21,12 +21,12 @@ import Test.Hspec (Spec, hspec, parallel)
 
 #if MIN_VERSION_base(4,7,0)
 import Data.Monoid (All(..))
+import Data.Proxy (Proxy(..))
 import Data.Type.Coercion (Coercion)
 
-import Spec.Utils (prop_matchesTextShow)
+import Spec.Utils (matchesTextShowSpec)
 
 import Test.Hspec (describe)
-import Test.Hspec.QuickCheck (prop)
 #endif
 
 main :: IO ()
@@ -36,7 +36,7 @@ spec :: Spec
 spec = parallel $
 #if MIN_VERSION_base(4,7,0)
     describe "Coercion All Bool" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> Coercion All Bool -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy (Coercion All Bool))
 #else
     pure ()
 #endif
