@@ -11,10 +11,10 @@ Portability: GHC
 module Spec.System.ExitSpec (main, spec) where
 
 import Data.Proxy (Proxy(..))
-import Instances.System.Exit ()
 import Spec.Utils (matchesTextShowSpec)
 import System.Exit (ExitCode)
 import Test.Hspec (Spec, describe, hspec, parallel)
+import Test.QuickCheck ()
 
 main :: IO ()
 main = hspec spec
